window.Gleam.initSearch([{"doc":"gen_core_erlang","title":"gen_core_erlang","content":"# Generate Core Erlang from Gleam\n\nThe result of any call is a single Core Erlang in-memory term. The intention of this library is that you compose these terms to construct a Core Erlang module, which you subsequently compile, load and run.\n\nWraps around the `cerl` module of the compiler application. Adds type safety of Gleam by wrapping the `c_erl()` type. Note: if you are programming Erlang, rather than using this package, use `cerl` directly.\n\nThis package specifically does not generate Core Erlang text and/or file.\n\n# Usage\n\nSee the tests for code examples.\n\n# Maturity\n\nNot all Core Erlang terms can be generated ,yet (see TODO.md), but some moderately complex code can be generated.\n","url":"index.html"},{"doc":"gen_core_erlang","title":"Clause","content":"pub type Clause\n\n\nSynonyms:\ngen_core_erlang.Clause\ngen_core_erlang Clause","url":"gen_core_erlang.html#Clause"},{"doc":"gen_core_erlang","title":"Definition","content":"pub type Definition =\n  #(FunctionDecl, Function)\n\n\nSynonyms:\ngen_core_erlang.Definition\ngen_core_erlang Definition","url":"gen_core_erlang.html#Definition"},{"doc":"gen_core_erlang","title":"Expression","content":"pub opaque type Expression\n Type that wraps the various `c_erl()` subtypes into an expression.\n These expressions are used as function bodies, in case clauses after `-&gt;`.\n\nSynonyms:\ngen_core_erlang.Expression\ngen_core_erlang Expression","url":"gen_core_erlang.html#Expression"},{"doc":"gen_core_erlang","title":"Function","content":"pub opaque type Function\n\n\nSynonyms:\ngen_core_erlang.Function\ngen_core_erlang Function","url":"gen_core_erlang.html#Function"},{"doc":"gen_core_erlang","title":"FunctionDecl","content":"pub type FunctionDecl\n Type that wraps name and arity, such as `loop/1`.\n\nSynonyms:\ngen_core_erlang.FunctionDecl\ngen_core_erlang FunctionDecl","url":"gen_core_erlang.html#FunctionDecl"},{"doc":"gen_core_erlang","title":"ModuleAttribute","content":"pub type ModuleAttribute\n\n\nSynonyms:\ngen_core_erlang.ModuleAttribute\ngen_core_erlang ModuleAttribute","url":"gen_core_erlang.html#ModuleAttribute"},{"doc":"gen_core_erlang","title":"ModuleDef","content":"pub type ModuleDef\n Outermost Core Erlang term that can be passed to `compile:forms(mod, [from_core])`.\n\nSynonyms:\ngen_core_erlang.ModuleDef\ngen_core_erlang ModuleDef","url":"gen_core_erlang.html#ModuleDef"},{"doc":"gen_core_erlang","title":"Pattern","content":"pub opaque type Pattern\n Type that wraps the various `c_erl()` subtypes into a pattern.\n These patterns are used as function arguments, in case clauses before `-&gt;`,\n\nSynonyms:\ngen_core_erlang.Pattern\ngen_core_erlang Pattern","url":"gen_core_erlang.html#Pattern"},{"doc":"gen_core_erlang","title":"c_apply","content":"pub fn c_apply(\n  f_def: FunctionDecl,\n  arguments: List(Expression),\n) -&gt; Expression\n\nSynonyms:\ngen_core_erlang.c_apply\ngen_core_erlang c_apply","url":"gen_core_erlang.html#c_apply"},{"doc":"gen_core_erlang","title":"c_apply_anonymous","content":"pub fn c_apply_anonymous(\n  function: Expression,\n  arguments: List(Expression),\n) -&gt; Expression\n Call a function, but not by name. Most likely, the function has been assigned\n to a variable\n \n c_let([p_var(&quot;Fun&quot;)], f2e(c_fun(...)), c_call_anonymous(c_var(&quot;Fun&quot;, [])))\n \nSynonyms:\ngen_core_erlang.c_apply_anonymous\ngen_core_erlang c_apply_anonymous","url":"gen_core_erlang.html#c_apply_anonymous"},{"doc":"gen_core_erlang","title":"c_atom","content":"pub fn c_atom(name: String) -&gt; Expression\n Create an expression for the atom that has string representation `name`\nSynonyms:\ngen_core_erlang.c_atom\ngen_core_erlang c_atom","url":"gen_core_erlang.html#c_atom"},{"doc":"gen_core_erlang","title":"c_binary","content":"pub fn c_binary(string: String) -&gt; Expression\n Create an Erlang binary for a Gleam string. Currently, there is no\n way to generate other binaries\nSynonyms:\ngen_core_erlang.c_binary\ngen_core_erlang c_binary","url":"gen_core_erlang.html#c_binary"},{"doc":"gen_core_erlang","title":"c_call","content":"pub fn c_call(\n  module: String,\n  name: String,\n  arguments: List(Expression),\n) -&gt; Expression\n Call an exported function\nSynonyms:\ngen_core_erlang.c_call\ngen_core_erlang c_call","url":"gen_core_erlang.html#c_call"},{"doc":"gen_core_erlang","title":"c_case","content":"pub fn c_case(\n  expr: Expression,\n  clauses: List(Clause),\n) -&gt; Expression\n\nSynonyms:\ngen_core_erlang.c_case\ngen_core_erlang c_case","url":"gen_core_erlang.html#c_case"},{"doc":"gen_core_erlang","title":"c_clause","content":"pub fn c_clause(\n  patterns: List(Pattern),\n  expr: Expression,\n) -&gt; Clause\n\nSynonyms:\ngen_core_erlang.c_clause\ngen_core_erlang c_clause","url":"gen_core_erlang.html#c_clause"},{"doc":"gen_core_erlang","title":"c_cons","content":"pub fn c_cons(head: Expression, tail: Expression) -&gt; Expression\n Concatenate two expressions. As per Erlang, the `tail` argument\n does not have to be a list. If you want to generate an empty list,\n use `c_nil`, if you want to generate a list from 1 or more items,\n use `make_list`\nSynonyms:\ngen_core_erlang.c_cons\ngen_core_erlang c_cons","url":"gen_core_erlang.html#c_cons"},{"doc":"gen_core_erlang","title":"c_float","content":"pub fn c_float(value: Float) -&gt; Expression\n\nSynonyms:\ngen_core_erlang.c_float\ngen_core_erlang c_float","url":"gen_core_erlang.html#c_float"},{"doc":"gen_core_erlang","title":"c_fname","content":"pub fn c_fname(name: String, arity: Int) -&gt; FunctionDecl\n Create a function &#39;name&#39; such as &quot;loop/1&quot;. To be used in module definitions\n (both exports and functions) as well as local function application\nSynonyms:\ngen_core_erlang.c_fname\ngen_core_erlang c_fname","url":"gen_core_erlang.html#c_fname"},{"doc":"gen_core_erlang","title":"c_fun","content":"pub fn c_fun(\n  arguments: List(Pattern),\n  body: Expression,\n) -&gt; Function\n If you need this as an `Expression`, use `f2e`\nSynonyms:\ngen_core_erlang.c_fun\ngen_core_erlang c_fun","url":"gen_core_erlang.html#c_fun"},{"doc":"gen_core_erlang","title":"c_int","content":"pub fn c_int(value: Int) -&gt; Expression\n\nSynonyms:\ngen_core_erlang.c_int\ngen_core_erlang c_int","url":"gen_core_erlang.html#c_int"},{"doc":"gen_core_erlang","title":"c_let","content":"pub fn c_let(\n  variables: List(Pattern),\n  argument: Expression,\n  body: Expression,\n) -&gt; Expression\n Equivalent to\n erlang\n &lt;P1, ..., Pn&gt; = argument\n body\n \n where you can use a pattern line `p_int(&quot;Num&quot;)` by its variable\n `c_int(&quot;Num&quot;)\nSynonyms:\ngen_core_erlang.c_let\ngen_core_erlang c_let","url":"gen_core_erlang.html#c_let"},{"doc":"gen_core_erlang","title":"c_module","content":"pub fn c_module(\n  name: String,\n  exports: List(FunctionDecl),\n  attributes: List(ModuleAttribute),\n  definitions: List(#(FunctionDecl, Function)),\n) -&gt; ModuleDef\n There should be a definition for each export. Other definitions are\n local functions.\n Note: For attributes, you currnely have to pass an empty list.\nSynonyms:\ngen_core_erlang.c_module\ngen_core_erlang c_module","url":"gen_core_erlang.html#c_module"},{"doc":"gen_core_erlang","title":"c_nil","content":"pub fn c_nil() -&gt; Expression\n Erlang&#39;s empty list.\nSynonyms:\ngen_core_erlang.c_nil\ngen_core_erlang c_nil","url":"gen_core_erlang.html#c_nil"},{"doc":"gen_core_erlang","title":"c_receive","content":"pub fn c_receive(clauses: List(Clause)) -&gt; Expression\n\nSynonyms:\ngen_core_erlang.c_receive\ngen_core_erlang c_receive","url":"gen_core_erlang.html#c_receive"},{"doc":"gen_core_erlang","title":"c_seq","content":"pub fn c_seq(arg: Expression, body: Expression) -&gt; Expression\n Execute two expression consecutively.\n Erlang functions always return a result. If you need that result, use `c_let`.\n If you want to execute more than 2 expressions, use:\n \n let assert Ok(expr) = list.reduce(expressions, c_seq)\n \nSynonyms:\ngen_core_erlang.c_seq\ngen_core_erlang c_seq","url":"gen_core_erlang.html#c_seq"},{"doc":"gen_core_erlang","title":"c_tuple","content":"pub fn c_tuple(values: List(Expression)) -&gt; Expression\n\nSynonyms:\ngen_core_erlang.c_tuple\ngen_core_erlang c_tuple","url":"gen_core_erlang.html#c_tuple"},{"doc":"gen_core_erlang","title":"c_var","content":"pub fn c_var(name: String) -&gt; Expression\n\nSynonyms:\ngen_core_erlang.c_var\ngen_core_erlang c_var","url":"gen_core_erlang.html#c_var"},{"doc":"gen_core_erlang","title":"f2e","content":"pub fn f2e(f: Function) -&gt; Expression\n\nSynonyms:\ngen_core_erlang.f2e\ngen_core_erlang f2e","url":"gen_core_erlang.html#f2e"},{"doc":"gen_core_erlang","title":"list_elements","content":"pub fn list_elements(list: Expression) -&gt; List(Expression)\n Unspecified behaviour. Used for testing this library.\nSynonyms:\ngen_core_erlang.list_elements\ngen_core_erlang list_elements","url":"gen_core_erlang.html#list_elements"},{"doc":"gen_core_erlang","title":"make_list","content":"pub fn make_list(expressions: List(Expression)) -&gt; Expression\n Convenience function, equivalent to\n \n c_cons(expr_1, .... c_cons(expr_n, c_nil()))\n \nSynonyms:\ngen_core_erlang.make_list\ngen_core_erlang make_list","url":"gen_core_erlang.html#make_list"},{"doc":"gen_core_erlang","title":"p_atom","content":"pub fn p_atom(name: String) -&gt; Pattern\n Create a pattern for the atom that has string representation `name`\nSynonyms:\ngen_core_erlang.p_atom\ngen_core_erlang p_atom","url":"gen_core_erlang.html#p_atom"},{"doc":"gen_core_erlang","title":"p_float","content":"pub fn p_float(value: Float) -&gt; Pattern\n\nSynonyms:\ngen_core_erlang.p_float\ngen_core_erlang p_float","url":"gen_core_erlang.html#p_float"},{"doc":"gen_core_erlang","title":"p_int","content":"pub fn p_int(value: Int) -&gt; Pattern\n\nSynonyms:\ngen_core_erlang.p_int\ngen_core_erlang p_int","url":"gen_core_erlang.html#p_int"},{"doc":"gen_core_erlang","title":"p_tuple","content":"pub fn p_tuple(values: List(Pattern)) -&gt; Pattern\n\nSynonyms:\ngen_core_erlang.p_tuple\ngen_core_erlang p_tuple","url":"gen_core_erlang.html#p_tuple"},{"doc":"gen_core_erlang","title":"p_var","content":"pub fn p_var(name: String) -&gt; Pattern\n\nSynonyms:\ngen_core_erlang.p_var\ngen_core_erlang p_var","url":"gen_core_erlang.html#p_var"},{"doc":"gen_core_erlang","title":"gen_core_erlang","content":"","url":"gen_core_erlang.html"}]);